@@ -1,6 +1,6 @@
 import json
 
-from docxtpl import DocxTemplate
+from docxtpl import DocxTemplate, RichText
 from termcolor import colored
 
 from scandb.models.report import ReportVuln
@@ -45,9 +45,25 @@ def db2ReportVulnAddress(v):
 def write_to_template(template, outfile, scan_stats=[], vuln_stats=[], port_stats=[], host_port_list=[],
                       vulns=[], vulns_by_plugin=[], vulns_by_host=[]):
     try:
+        # ensure to handle the plugin_output fields a RichText, so that these field doesn't cause an error when they
+        # contain html
+        for i in vulns_by_plugin:
+            for a in i.addresses:
+                a.plugin_output = RichText(a.plugin_output)
+        for i in vulns:
+            i.plugin_output = RichText(i.plugin_output)
+        for i in vulns_by_host:
+            for v in i.vulns:
+                v.plugin_output = RichText(v.plugin_output)
+        # inject the given object into the template engine and render the template
         doc = DocxTemplate(template)
-        context = {'vulns' : vulns, 'scan_stats' : scan_stats, 'vuln_stats': vuln_stats, 'port_stats' : port_stats,
-                   'vulns_by_plugin': vulns_by_plugin, 'vulns_by_host': vulns_by_host, 'host_port_list': host_port_list}
+        context = {'vulns' : vulns,
+                   'scan_stats' : scan_stats,
+                   'vuln_stats': vuln_stats,
+                   'port_stats' : port_stats,
+                   'vulns_by_plugin': vulns_by_plugin,
+                   'vulns_by_host': vulns_by_host,
+                   'host_port_list': host_port_list}
         doc.render(context)
         doc.save(outfile)
     except Exception as e:
